@@ -1,7 +1,7 @@
 import json
 from utils.APIV3 import EtsySession
 from resources import ListingResource, ReceiptResource
-from models.ReceiptModel import ReceiptType
+from models import Receipt, Transaction, Variation
 import time
 import asyncio
 
@@ -15,7 +15,7 @@ TOKEN = {'access_token': '486257382.UxSUw5JyN6ePR2uUV_r3XZMM-z7aDhdJV-TKqNKpjvkI
 
 SHOP_ID = 20641892
 
-session = EtsySession(client_key=FALKEL_CLIENT_KEY, client_secret=FALKEL_CLIENT_SECRET, token=FALKEL_TOKEN)
+session = EtsySession(client_key=CLIENT_KEY, client_secret=CLIENT_SECRET, token=TOKEN)
 auth = session.create_auth()
 
 resource = ListingResource(auth)
@@ -26,7 +26,7 @@ receipts = []
 
 start_time = time.time()
 
-
+"""
 
 async def get_receipts(offset: int):
     receipts = resource_.find(SHOP_ID, limit=100, offset=offset, type=ReceiptType.PAID).results
@@ -45,21 +45,43 @@ async def main():
 asyncio.run(main())
 
 print(f"Finish Time: {time.time() - start_time}")
+"""
 
-"""inventory = resource.get_listing_inventory(listing_id=1260997739)
+inventory = resource.get_listing_inventory(listing_id=1260997739)
 #print(inventory)
 products = []
+
+
+
+new_sku = "esat321321"
+add_last = False
+add_prefix = True
+change_price = 1000
+new_qty = 500
+
+
 for product in inventory.products:
     
-    product_json = product.dict(include={"sku"})
-    product_json["offerings"] = [{"price":float(offer.price.amount), "quantity":offer.quantity, "is_enabled":offer.is_enabled} for offer in product.offerings]
+    product_json = {"sku":"", "property_values":[], "offerings":[]}
+    if new_sku:
+        product_json["sku"] = new_sku
+    
+    for offering in product.offerings:
+        offering.quantity = new_qty
+        product_json["offerings"].append({
+            "price":offering.price.amount / offering.price.divisor,
+            "quantity":offering.quantity,
+            "is_enabled":offering.is_enabled}
+        )
+    
     product_json["property_values"] = [property_values.dict(include={"property_id", "property_name", "scale_id", "value_ids", "values"}) for property_values in product.property_values]
 
     products.append(product_json)
-products[0]["sku"] = "test1"
-products[1]["sku"] = "test2"
+
+#print(inventory.json())
+
 #print(json.dumps({"products":products}))
 
-response = resource.update_listing_inventory(1260997739, products)
+response = resource.update_listing_inventory(1260997739, products, inventory.price_on_property, inventory.quantity_on_property, inventory.sku_on_property)
 
-#print(response)"""
\ No newline at end of file
+print(response)
\ No newline at end of file
