@@ -107,9 +107,7 @@ class ListingResource:
             data["sku_on_property"] = sku_on_property
             
         endpoint = f"listings/{listing_id}/inventory"
-        print(json.dumps(data))
-        print(endpoint)
-        response = self.auth.request(endpoint, "PUT", data=json.dumps(data))
+        response = self.auth.request(endpoint, "PUT", json=data)
         return Inventory(**response)
 
     
