@@ -29,7 +29,7 @@ class EtsyAuth:
     def __post_init__(self):
         user_info_endpoint = "oauth/userinfo"
         response = self.request(user_info_endpoint, params={"client_id":self.session.client_id})
-        setattr(self, "user_info", OtherUser(**response))
+        object.__setattr__(self, "user_info", OtherUser(**response))
     
     @property
     def get_shop_id_self_user(self):
